////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//  OBPDFViewModel.h
//    Model component in MVC for PDF generation support.
//
//  Copyright (C) 2010 MYOB US, Inc., all rights reserved.
//
//  Change History (most recent first):
//
//	09/16/10  K.L.S.  Created file.
//
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>

@interface OBPDFViewElement : NSObject
{
	NSRect frame;
	NSRect clipRect;
	BOOL dashedLine;
}

-(id)initWithFrame:(NSRect)frame;

-(NSRect)frame;
-(void)setFrame:(NSRect)newFrame;

-(NSRect)clipRect;
-(void)setClipRect:(NSRect)clipRect;

-(BOOL)dashedLine;
-(void)setDashedLine:(BOOL)isDashedLine;

@end


@interface PDFRectangleViewElement : OBPDFViewElement
{
	NSColor* frameColor;
	NSColor* fillColor;
	float lineWidth;
	float radius;
}

+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor
							lineWidth:(float)aLineWidth radius:(float)radius dashedLine:(BOOL)dashedLine;
+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth
						   dashedLine:(BOOL)dashedLine;
+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor;
+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor lineWidth:(float)aLineWidth dashedLine:(BOOL)dashedLine;
+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor;
+(id)PDFRectangleViewElementWithFrame:(NSRect)aFrame fillColor:(NSColor*)aFillColor;

-(id)initWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth
	radius:(float)radius dashedLine:(BOOL)dashedLine;
-(id)initWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth dashedLine:(BOOL)dashedLine;
-(id)initWithFrame:(NSRect)aframe frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor;
-(id)initWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor lineWidth:(float)aLineWidth dashedLine:(BOOL)dashedLine;
-(id)initWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor;
-(id)initWithFrame:(NSRect)aFrame fillColor:(NSColor*)aFillColor;
-(id)init;

-(NSColor*)frameColor;
-(void)setFrameColor:(NSColor*)aColor;

-(NSColor*)fillColor;
-(void)setFillColor:(NSColor*)aColor;

-(float)lineWidth;
-(void)setLineWidth:(float)aLineWidth;

-(float)radius;
-(void)setRadius:(float)aRadius;

-(BOOL)isFilled;

@end

@interface PDFOvalViewElement : OBPDFViewElement
{
	NSColor* frameColor;
	NSColor* fillColor;
	float lineWidth;
}

+(id)PDFOvalViewElementWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth
					  dashedLine:(BOOL)dashedLine;

-(id)initWithFrame:(NSRect)aFrame frameColor:(NSColor*)aFrameColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth
		dashedLine:(BOOL)dashedLine;
-(id)init;

-(NSColor*)frameColor;
-(void)setFrameColor:(NSColor*)aColor;

-(NSColor*)fillColor;
-(void)setFillColor:(NSColor*)aColor;

-(float)lineWidth;
-(void)setLineWidth:(float)aLineWidth;
@end


@interface PDFTextViewElement : OBPDFViewElement
{
	NSString* text;
	NSDictionary* textAttributes;
}

+(id)PDFTextViewElementWithFrame:(NSRect)frame text:(NSString*)text textAttributes:(NSDictionary*)textAttributes;

-(id)initWithFrame:(NSRect)frame text:(NSString*)text textAttributes:(NSDictionary*)textAttributes;

-(NSString*)text;
-(void)setText:(NSString*)newText;

-(NSDictionary*)textAttributes;
-(void)setTextAttributes:(NSDictionary*)newTextAttributes;

@end

@interface PDFPolygonViewElement : OBPDFViewElement
{
	NSData* points;
	NSColor* lineColor;
	NSColor* fillColor;
	float lineWidth;
}

+(id)PDFPolygonViewElementWithPoints:(NSData*)pointsArray lineColor:(NSColor*)aLineColor fillColor:(NSColor*)aFillColor
						   lineWidth:(float)aLineWidth dashedLine:(BOOL)aDashedLine;

-(id)initWithPoints:(NSData*)pointsArray lineColor:(NSColor*)aLineColor fillColor:(NSColor*)aFillColor lineWidth:(float)aLineWidth
		 dashedLine:(BOOL)aDashedLine;

-(NSData*)points;
-(void)setPoints:(NSData*)newPoints;

-(NSPointArray)pointArray;
-(NSUInteger)pointCount;

-(NSColor*)lineColor;
-(void)setLineColor:(NSColor*)aColor;

-(NSColor*)fillColor;
-(void)setFillColor:(NSColor*)aColor;

-(float)lineWidth;
-(void)setLineWidth:(float)aLineWidth;

@end

@interface PDFImageViewElement : OBPDFViewElement
{
	NSImage* image;
}

+(id)PDFImageViewElement:(NSImage*)image inDestinationRect:(NSRect)rect;
+(id)PDFImageViewElement:(NSImage*)image inDestinationRect:(NSRect)rect withClipRect:(NSRect)clipRect;

-(id)initWithImage:(NSImage*)image inDestinationRect:(NSRect)rect;
-(id)initWithImage:(NSImage*)imageIn inDestinationRect:(NSRect)rect withClipRect:(NSRect)clipRect;

-(NSImage*)image;
-(void)setImage:(NSImage*)newImage;

-(NSRect)destinationRect;
-(void)setDestinationRect:(NSRect)rect;

@end

@interface OBPDFViewModel : NSObject
{
@private	
	NSMutableArray* pdfViewElements;
	NSMutableArray* lastViewElementOfEachPage;
	NSUInteger pageCount;
}

-(id)init;

-(NSArray*)pdfViewElements;

-(void)addPDFViewElement:(OBPDFViewElement*)viewElement;

-(NSUInteger)pageCount;
-(void)setPageCount:(NSUInteger)newPageCount;
-(void)incrementPageCount;

-(long)firstViewElementforPage:(NSUInteger)page;
-(long)lastViewElementforPage:(NSUInteger)page;

@end
